// Shim for extensions/core/maskeditor/utils/clipspace.ts
console.warn('[ComfyUI Notice] "extensions/core/maskeditor/utils/clipspace.js" is an internal module, not part of the public API. Future updates may break this import.');
export const replaceClipspaceImages = window.comfyAPI.clipspace.replaceClipspaceImages;
