var n=Object.defineProperty;var l=(e,a)=>n(e,"name",{value:a,configurable:!0});import{defineComponent as c,ref as i,computed as s,openBlock as p,createBlock as u,unref as m}from"vue";import v from"primevue/avatar";const b=c({__name:"UserAvatar",props:{photoUrl:{},ariaLabel:{}},setup(e){const a=i(!1),t=l(()=>{a.value=!0},"handleImageError"),o=s(()=>e.photoUrl&&!a.value);return(r,f)=>(p(),u(m(v),{class:"bg-gray-200 dark-theme:bg-[var(--interface-panel-selected-surface)]",image:r.photoUrl??void 0,icon:o.value?void 0:"icon-[lucide--user]","pt:icon:class":{"size-4":!o.value},shape:"circle","aria-label":r.ariaLabel??r.$t("auth.login.userAvatar"),onError:t},null,8,["image","icon","pt:icon:class","aria-label"]))}});export{b as _};
//# sourceMappingURL=UserAvatar.vue_vue_type_script_setup_true_lang-Buu-YWwg.js.map
