// Shim for extensions/core/maskeditor/utils/brushCache.ts
console.warn('[ComfyUI Notice] "extensions/core/maskeditor/utils/brushCache.js" is an internal module, not part of the public API. Future updates may break this import.');
export const saveBrushToCache = window.comfyAPI.brushCache.saveBrushToCache;
export const loadBrushFromCache = window.comfyAPI.brushCache.loadBrushFromCache;
