// Shim for extensions/core/maskEditorOld.ts
console.warn('[ComfyUI Deprecated] Importing from "extensions/core/maskEditorOld.js" is deprecated and will be removed in v1.34.');
export const MaskEditorDialogOld = window.comfyAPI.maskEditorOld.MaskEditorDialogOld;
