var i=Object.defineProperty;var r=(t,o)=>i(t,"name",{value:o,configurable:!0});import"vue";import"./vendor-other-CxTHhkh8.js";import"./index-1hU-CrHv.js";import"primevue/button";import"vue-i18n";import"primevue/checkbox";import"primevue/message";import"primevue/divider";import"primevue/scrollpanel";import"primevue/usetoast";import"primevue/card";import"primevue/listbox";import"./vendor-xterm-DV1MVhAx.js";import"primevue/progressspinner";import"primevue/skeleton";import"primevue/galleria";import"primevue/popover";import"primevue/iconfield";import"primevue/inputicon";import"primevue/inputtext";import"primevue/badge";import"primevue/chip";import"primevue/contextmenu";import"primevue/tree";import"primevue/toolbar";import"primevue/progressbar";import"primevue";import"primevue/select";import"primevue/selectbutton";import"primevue/tag";import"primevue/dialog";import"primevue/colorpicker";import"primevue/confirmpopup";import"primevue/useconfirm";import"primevue/confirmdialog";import"primevue/floatlabel";import"@primevue/forms";import"@primevue/forms/resolvers/zod";import"primevue/password";import"primevue/inputnumber";import"primevue/tabpanels";import"primevue/tabs";import"primevue/tabpanel";import"primevue/toggleswitch";import"primevue/radiobutton";import"primevue/knob";import"primevue/slider";import"primevue/panel";import"primevue/tabmenu";import"primevue/tab";import"primevue/tablist";let m=null;function ir(){return m}r(ir,"useTelemetry");export{ir as u};
//# sourceMappingURL=index-M4bGAyCb.js.map
