// Shim for extensions/core/maskeditor/managers/MessageBroker.ts
console.warn('[ComfyUI Notice] "extensions/core/maskeditor/managers/MessageBroker.js" is an internal module, not part of the public API. Future updates may break this import.');
export const MessageBroker = window.comfyAPI.MessageBroker.MessageBroker;
