// Shim for extensions/core/maskeditor/CanvasHistory.ts
console.warn('[ComfyUI Notice] "extensions/core/maskeditor/CanvasHistory.js" is an internal module, not part of the public API. Future updates may break this import.');
export const CanvasHistory = window.comfyAPI.CanvasHistory.CanvasHistory;
