[data-v-19217ad4] .p-inputtext{border-top-left-radius:0;border-bottom-left-radius:0}.comfyui-queue-button[data-v-5de51bf4] .p-splitbutton-dropdown{border-top-right-radius:0;border-bottom-right-radius:0}
